==> Echoes-of-Power-2.4.3.jar: addon/sgoc/kubejs_scripts/pocket_travel.js <==

    StartupEvents.registry('palladium:abilities', (event) => {
        event.create('sgoc:pocket_travel')
		.icon(palladium.createItemIcon('sgoc:logo'))
        .documentationDescription('Teleports you to a dimension.')
        .addProperty("id_scoreboard", "string", "Whatever", "Scoreboard for dimesions ID's")
        .addProperty("dimension_id", "string", "minecraft:the_overworld", "Dimension to teleport to")
					
            .tick((entity, entry, holder, enabled) => {
                if (enabled) {				
				let dimension = entity.getLevel().getDimension();
                let username = entity.username;
				let scoreboard = Utils.server.scoreboard;
                let scoreboard_obj = scoreboard.getObjective(entry.getPropertyByName("id_scoreboard"));
                let score = scoreboard.getOrCreatePlayerScore(username, scoreboard_obj);
                let value = score.getScore();
				const dim_id = entry.getPropertyByName('dimension_id');
				const score_id = entry.getPropertyByName('id_scoreboard');
				if (dimension.toString() != dim_id.toString()) {
				entity.persistentData.pocket_dim = dimension.toString()
				entity.persistentData.pocket_x = entity.getX();
				entity.persistentData.pocket_y = entity.getY();
				entity.persistentData.pocket_z = entity.getZ();
				let coord_x_b = entity.persistentData.coord_x_leave
				if (coord_x_b == null || coord_x_b > (value * 250) || coord_x_b < (value * 250)) {
				entity.persistentData.coord_x_leave = (value * 250)
				coord_x_b = (value * 250)
				}
				let coord_y_b = entity.persistentData.coord_y_leave
				if (coord_y_b == null || coord_y_b > 176 || coord_y_b < 176) {
				entity.persistentData.coord_y_leave = 57
				coord_y_b = 57
				}
				let coord_z_b = entity.persistentData.coord_z_leave
				if (coord_z_b == null || coord_z_b > (value * 250) || coord_z_b < (value * 250)) {
				entity.persistentData.coord_z_leave = (value * 250)
				coord_z_b = (value * 250)
				}
				entity.server.runCommandSilent("execute as " + username + " at @s in " + dim_id + " positioned " + (value * 250) + " 57 " + (value * 250) + " run summon minecraft:armor_stand ~ ~ ~ {Palladium:{Properties:{superpowers:[\"sgoc:models/pocket_dimension_area\"]}},Invisible:1,NoGravity:1}");	
				entity.server.runCommandSilent("execute as " + username + " at @s as @e[tag=!PD.Permission.Denied,distance=..2,type=!armor_stand,type=!marker] in " + dim_id + " positioned " + coord_x_b + " " + coord_y_b + " " + coord_z_b + " run tp @s ~ ~ ~");
				entity.server.runCommandSilent("execute as " + username + " as @s at @s in " + dim_id + " run forceload add " + (value * 250) + " " + (value * 250) + " " + (value * 250) + " " + (value * 250));
				entity.server.runCommandSilent("execute as " + username + " as @s at @s in " + dim_id + " run forceload remove " + (value * 250) + " " + (value * 250) + " " + (value * 250) + " " + (value * 250));
				}
				if (dimension.toString() == dim_id.toString()) {
				entity.persistentData.coord_x_leave = entity.getX();
				entity.persistentData.coord_y_leave = entity.getY();
				entity.persistentData.coord_z_leave = entity.getZ();
				let original_dim = entity.persistentData.pocket_dim;
				let coord_x = entity.persistentData.pocket_x;
				let coord_y = entity.persistentData.pocket_y;
				let coord_z = entity.persistentData.pocket_z;
				entity.server.runCommandSilent("execute as " + username + " at @s as @e[tag=!PD.Permission.Denied,distance=..2,type=!marker,type=!armor_stand] in " + original_dim + " run tp @s " + coord_x + " " + coord_y + " " + coord_z);
				}
					
                }
          
		});
    });

==> Echoes-of-Power-2.4.6.jar: addon/sgoc/kubejs_scripts/pocket_travel.js <==

    StartupEvents.registry('palladium:abilities', (event) => {
        event.create('sgoc:pocket_travel')
		.icon(palladium.createItemIcon('sgoc:logo'))
        .documentationDescription('Teleports you to a dimension.')
        .addProperty("id_scoreboard", "string", "Whatever", "Scoreboard for dimesions ID's")
        .addProperty("dimension_id", "string", "minecraft:the_overworld", "Dimension to teleport to")
					
            .tick((entity, entry, holder, enabled) => {
                if (enabled) {				
				let dimension = entity.getLevel().getDimension();
                let username = entity.username;
				let scoreboard = Utils.server.scoreboard;
                let scoreboard_obj = scoreboard.getObjective(entry.getPropertyByName("id_scoreboard"));
                let score = scoreboard.getOrCreatePlayerScore(username, scoreboard_obj);
                let value = score.getScore();
				const dim_id = entry.getPropertyByName('dimension_id');
				const score_id = entry.getPropertyByName('id_scoreboard');
				if (dimension.toString() != dim_id.toString()) {
				entity.persistentData.pocket_dim = dimension.toString()
				entity.persistentData.pocket_x = entity.getX();
				entity.persistentData.pocket_y = entity.getY();
				entity.persistentData.pocket_z = entity.getZ();
				let coord_x_b = entity.persistentData.coord_x_leave
				if (coord_x_b == null || coord_x_b > (value * 250) || coord_x_b < (value * 250)) {
				entity.persistentData.coord_x_leave = (value * 250)
				coord_x_b = (value * 250)
				}
				let coord_y_b = entity.persistentData.coord_y_leave
				if (coord_y_b == null || coord_y_b > 176 || coord_y_b < 176) {
				entity.persistentData.coord_y_leave = 57
				coord_y_b = 57
				}
				let coord_z_b = entity.persistentData.coord_z_leave
				if (coord_z_b == null || coord_z_b > (value * 250) || coord_z_b < (value * 250)) {
				entity.persistentData.coord_z_leave = (value * 250)
				coord_z_b = (value * 250)
				}
				entity.server.runCommandSilent("execute as " + username + " at @s in " + dim_id + " positioned " + (value * 250) + " 57 " + (value * 250) + " run summon minecraft:armor_stand ~ ~ ~ {Palladium:{Properties:{superpowers:[\"sgoc:models/pocket_dimension_area\"]}},Invisible:1,Invulnerable:1,NoGravity:1}");	
				entity.server.runCommandSilent("execute as " + username + " at @s as @e[tag=!PD.Permission.Denied,distance=..2,type=!armor_stand,type=!marker] in " + dim_id + " positioned " + coord_x_b + " " + coord_y_b + " " + coord_z_b + " run tp @s ~ ~ ~");
				entity.server.runCommandSilent("execute as " + username + " as @s at @s in " + dim_id + " run forceload add " + (value * 250) + " " + (value * 250) + " " + (value * 250) + " " + (value * 250));
				entity.server.runCommandSilent("execute as " + username + " as @s at @s in " + dim_id + " run forceload remove " + (value * 250) + " " + (value * 250) + " " + (value * 250) + " " + (value * 250));
				}
				if (dimension.toString() == dim_id.toString()) {
				entity.persistentData.coord_x_leave = entity.getX();
				entity.persistentData.coord_y_leave = entity.getY();
				entity.persistentData.coord_z_leave = entity.getZ();
				let original_dim = entity.persistentData.pocket_dim;
				let coord_x = entity.persistentData.pocket_x;
				let coord_y = entity.persistentData.pocket_y;
				let coord_z = entity.persistentData.pocket_z;
				entity.server.runCommandSilent("execute as " + username + " at @s as @e[tag=!PD.Permission.Denied,distance=..2,type=!marker,type=!armor_stand] in " + original_dim + " run tp @s " + coord_x + " " + coord_y + " " + coord_z);
				}
					
                }
          
		});
    });
